package info.jedi.testsuite;

import java.io.*;
import java.util.*;

	/** A ComplexObject is a Serializable amalgamation of multiple other
	 * objects.  If created with the proper parameters, this may include
	 * a branched tree-like structure containing other ComplexObjects.
	 *
	 * A ComplexObject has one queryable field, an integer value.  When
	 * the object is touch()ed, this value is returned and incremented.
	 */
public class ComplexObject implements Serializable
{
		/** Creates a ComplexObject.  It is given a particular value
		 * and a particular level of branching.  The ComplexObject
		 * will create level other ComplexObjects underneath it in
		 * a tree created with parameters value+1 and level-1.  These
		 * ComplexObjects will be added both to the Vector and
		 * Hashtable that is contained by this ComplexObject.
		 */
	public ComplexObject(int value, int level)
	{
		this.value = value;
		vector = new Vector();
		hashtable = new Hashtable();
		if (level > 0)
		{
			objects = new Object[level];
			for (int i = 0; i < level; ++i)
			{
				objects[i] = new ComplexObject(value+1, level-1);
				vector.addElement(objects[i]);
				hashtable.put(new Integer(i), objects[i]);
			}
		}
	
		random = Integer.toString((int)System.currentTimeMillis());
	}

		/** Touch this ComplexObject.  Returns the current value of the
		 * object, and increments it so the next call to touch() will
		 * return a value greater by one.
		 */
	public int touch()
	{
		return value++;
	}

		/** The value of this ComplexObject */
	private int value;
		/** The string representation of the time in milliseconds when
		 * this ComplexObject was created */
	private String random;
		/** An array containing the lower-level ComplexObjects in this
		 * ComplexObject */
	private Object objects[];
		/** A Vector containing the lower-level ComplexObjects in this
		 * ComplexObject */
	private Vector vector;
		/** A Hashtable containing the lower-level ComplexObjects in
		 * this ComplexObject */
	private Hashtable hashtable;
}
